Title: 使用 Tableau Agent 探索您的数据

URL Source: https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm

Markdown Content:
使用 Tableau Agent 探索您的数据 - Tableau
===============

[![Image 19: Tableau](https://help.tableau.com/current/online/zh-cn/Resources/tableau-logo.png)](https://www.tableau.com/zh-cn/)

有关最新信息，请参见 [Tableau 帮助(美国英语)](https://help.tableau.com/current/online/en-us/web_author_einstein.htm)。

Tableau Cloud 帮助
================

1.   [Tableau 帮助](https://www.tableau.com/zh-cn/support/help)
2.   [Tableau Cloud 帮助](https://help.tableau.com/current/online/zh-cn/tableau-online-home.htm)
3.   [在 Web 上创建视图并探索数据](https://help.tableau.com/current/online/zh-cn/web_author.htm)
4.   [使用 Tableau Agent 探索您的数据](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

本文内容

*   [Tableau Agent 和信任](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#tableau-agent-%E5%92%8C%E4%BF%A1%E4%BB%BB)
*   [Tableau Agent 计费注意事项](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#tableau-agent-%E8%AE%A1%E8%B4%B9%E6%B3%A8%E6%84%8F%E4%BA%8B%E9%A1%B9)
*   [Tableau Agent 入门指南](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#tableau-agent-%E5%85%A5%E9%97%A8%E6%8C%87%E5%8D%97)
*   [启动 Tableau Agent](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E5%90%AF%E5%8A%A8-tableau-agent)
*   [构建和更改可视化项](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E6%9E%84%E5%BB%BA%E5%92%8C%E6%9B%B4%E6%94%B9%E5%8F%AF%E8%A7%86%E5%8C%96%E9%A1%B9)
*   [使用建议快速开始分析](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E4%BD%BF%E7%94%A8%E5%BB%BA%E8%AE%AE%E5%BF%AB%E9%80%9F%E5%BC%80%E5%A7%8B%E5%88%86%E6%9E%90)
*   [创建计算](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E5%88%9B%E5%BB%BA%E8%AE%A1%E7%AE%97)
*   [使用筛选器](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E4%BD%BF%E7%94%A8%E7%AD%9B%E9%80%89%E5%99%A8)
*   [对话历史记录和可视化项重新创建](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E5%AF%B9%E8%AF%9D%E5%8E%86%E5%8F%B2%E8%AE%B0%E5%BD%95%E5%92%8C%E5%8F%AF%E8%A7%86%E5%8C%96%E9%A1%B9%E9%87%8D%E6%96%B0%E5%88%9B%E5%BB%BA)
*   [从 Tableau Agent 获得最佳结果的技巧](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E4%BB%8E-tableau-agent-%E8%8E%B7%E5%BE%97%E6%9C%80%E4%BD%B3%E7%BB%93%E6%9E%9C%E7%9A%84%E6%8A%80%E5%B7%A7)
*   [实现人机回环](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E5%AE%9E%E7%8E%B0%E4%BA%BA%E6%9C%BA%E5%9B%9E%E7%8E%AF)
*   [Tableau Agent 限制](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#tableau-agent-%E9%99%90%E5%88%B6)
*   [分析的类型](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E5%88%86%E6%9E%90%E7%9A%84%E7%B1%BB%E5%9E%8B)
*   [不支持的功能](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E4%B8%8D%E6%94%AF%E6%8C%81%E7%9A%84%E5%8A%9F%E8%83%BD)
*   [此部分中的其他文章](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E6%AD%A4%E9%83%A8%E5%88%86%E4%B8%AD%E7%9A%84%E5%85%B6%E4%BB%96%E6%96%87%E7%AB%A0)

 内容 
*   [Tableau Cloud 帮助](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

*   [入门指南](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
    *   [Tableau Cloud 发行说明](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [以前版本的 Tableau Cloud 中引入的功能](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [登录 Tableau Cloud](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [了解许可证模式](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用基于登录名的许可证管理激活 Tableau](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [站点管理员速查表：Salesforce 集成](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用 Salesforce 数据创建工作簿](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [关于 Tableau+](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [Tableau+ 入门](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [关于 Tableau Enterprise](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

*   [使用 Tableau Cloud Manager](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
    *   [云管理员角色和任务](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [登录 Tableau Cloud Manager](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [Tableau Cloud Manager 身份验证](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [Tableau Cloud Manager 的个人访问令牌](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [添加、删除或激活站点](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [管理站点角色限制](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用 Tableau Cloud Manager 管理用户](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [设置适用于 AWS 的私人连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

*   [管理站点](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
    *   [在 Web UI 的管理区域中导航](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [自定义站点和内容设置](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [站点设置参考](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [将自定义域与 Tableau Cloud 配合使用](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [为 Tableau Cloud 配置 IP 筛选器](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [为您的站点启用 Tableau 中的 AI](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [为站点上载自定义徽标](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [自助环境的自定义门户](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [为所有用户设置默认开始页面](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [为数据提取设置站点时区](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [Tableau Mobile 应用程序安全设置](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [云中的安全性](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [为数据提取加密密钥使用外部 KMS](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [客户管理的加密密钥](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [站点容量](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [关于 Tableau 发布预览](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [系统维护](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [站点身份验证](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [多重身份验证和 Tableau Cloud](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [Google 身份验证](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [OpenID Connect](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [针对 OpenID Connect 配置身份提供程序](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [针对 OpenID Connect 配置 Tableau Cloud 或 TCM](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [Salesforce 身份验证](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [SAML](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [Tableau Cloud 的 SAML 要求](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [为站点启用 SAML 单点登录](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [使用 Microsoft Entra ID 配置 SAML](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [使用 AD FS 配置 SAML](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [使用 OneLogin 配置 SAML](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [使用 PingOne 配置 SAML](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [使用 Okta 配置 SAML](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [使用 Salesforce 配置 SAML](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [为 Tabbleau Viz Lightning Web 组件配置 SAML](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [SAML 疑难解答](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [SCIM](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [使用 Microsoft Entra ID 配置 SCIM](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [使用 Okta 配置 SCIM](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [使用 OneLogin 配置 SCIM](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [使用 PingFederate 配置 SCIM](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [使用 Tableau 已连接应用进行应用程序集成](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [使用直接信任配置已连接应用](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [使用 OAuth 2.0 信任配置已连接应用](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [已连接应用的访问范围](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [已连接应用故障排除 - 直接信任](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [个人访问令牌](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [直接从连接的客户端中访问站点](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [监视站点活动](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [查找管理视图](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [使用“在线管理见解”创建自定义视图](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [管理“在线管理见解”](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [“TS 事件”数据源](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [“TS 用户”数据源](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [组数据源](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [“站点内容”数据源](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [“可视化项加载时间”数据源。](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [“作业性能”数据源](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [权限数据源](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [“订阅”数据源](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [“令牌”数据源](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [到 Bridge 连接数据源的流量](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [数据提取后台任务](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [Bridge 数据提取](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [非数据提取后台任务](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [数据问答功能使用情况](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [数据质量警告历史记录](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [流程的管理视图](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [数据提取刷新失败时通知数据所有者](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [管理用户和组](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [向站点添加用户](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [设置用户的站点角色](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [查看、管理或移除用户](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [设置用户身份验证类型](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [导入用户](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [CSV 导入文件准则](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [管理用户可见性](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [启用支持访问权限](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [创建组并向其中添加用户](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [登录时授予角色（登录时授予许可证）](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [购买更多许可证](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [删除组](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [使用组集](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [管理项目和内容访问](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [针对内容设置 Web 编辑、保存和下载访问权限](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [配置托管自助服务的项目](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [使用项目管理内容访问权限](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [添加项目并将内容移至其中](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [添加项目图像](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [允许用户请求访问内容和项目](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [设置权限和所有权](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [权限能力和模板](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [使用项目管理权限](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [有效权限](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [权限、站点角色和许可证](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [快速开始：设置权限](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [管理内容所有权](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [管理外部资产的权限](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [回收站](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [启用 Tableau Catalog](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [为影响分析使用世系](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [数据标签](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [使用认证来帮助用户查找受信任的数据](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [设置数据质量警告](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [敏感度标签](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [具有自定义类别的标签](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [管理数据标签](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [在 Tableau Cloud 中管理仪表板扩展程序和可视化项扩展程序](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [配置与分析扩展程序的连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [表扩展程序](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [配置 Einstein Discovery 集成](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [在 Salesforce.com 中为 Einstein Discovery 集成配置 CORS](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [将 Tableau 与 Slack 集成](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用适用于 Slack 的 Tableau 应用程序](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [为 Microsoft Teams 设置 Tableau 应用](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [在 Microsoft Teams 中访问 Tableau 内容](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用 tabcmd 自动完成任务](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [安装 tabcmd](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [tabcmd 命令](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [tabcmd 的安装开关和属性 (Windows)](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [在 Tableau Cloud 中管理后台作业](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

*   [管理数据](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
    *   [Creator：连接到 Web 上的数据](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [运行初始 SQL](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [数据提取升级为 .hyper 格式](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [在 Web 上创建数据提取](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使数据保持最新](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [允许直接连接到云数据](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [Tableau 中的行级安全性选项概述](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [配置与分析扩展程序的连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [表扩展程序](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用认证来帮助用户查找受信任的数据](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [刷新失败时接收电子邮件](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [刷新 Tableau Cloud 上的数据](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [在 Tableau Cloud 上计划刷新](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [使用保存的凭据刷新数据](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [手动启动刷新任务](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [管理刷新任务](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [自动挂起非活动工作簿的数据提取刷新](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用 Tableau Bridge](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [使用 Bridge 使数据保持最新](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [Tableau Bridge 常见问题解答](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [计划 Bridge 部署](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [Bridge 站点容量](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [安装 Bridge](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [安装 Windows 客户端](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [为容器安装 Linux 版 Bridge](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [与 Bridge 的连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [更新 Bridge 连接信息](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [发布包含实时连接的私有网络数据源](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [使用嵌入式数据源](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [优化 Bridge 刷新性能](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [设置私有网络刷新计划](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [连接到私有云数据](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [配置池](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [管理池](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [关于 Bridge 客户端](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [更改 Bridge 客户端设置](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [更改 Windows 客户端服务](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [通过 Bridge 停止使数据保持最新](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [停止通过 Windows 客户端刷新数据](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [针对 Bridge 管理电子邮件通知](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [Bridge 安全性](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [排查 Bridge 的问题](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [适用于私有网络数据的 Data Connect](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [关于 Data Connect](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [Data Connect 安全性](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [规划您的 Data Connect 部署](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [部署 Data Connect](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [管理 Data Connect](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [使用 Data Connect 进行发布](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [适用于 AWS 的私人连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [专用连接设置：概述](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [私有连接设置：AWS](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [适用于 Athena 的私人连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [适用于 AuroraMySQL 的私人连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [适用于 Dremio Server 的私人连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [适用于 Heroku Postgres 的私人连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [适用于 MariaDB 的私人连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [适用于 Microsoft SQL 的私人连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [适用于 MySQL 的私人连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [适用于 Oracle 的私人连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [适用于 PostgreSQL 的私人连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [适用于 Redshift 的私人连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [适用于 Snowflake 的私人连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [适用于 Teradata Vantage Cloud 的私人连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [适用于 Teradata Vantage 本地部署的私人连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [专用连接设置：Tableau Cloud](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [列出和共享专用连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [从 Tableau Bridge 迁移到私人连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [从 Tableau Desktop 中刷新已发布数据提取](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [从命令行中自动执行刷新](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [针对数据驱动型通知进行设置](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [针对指标进行设置](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [排查刷新问题](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [订阅疑难解答](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [管理连接信息](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [编辑 Tableau Cloud 上的连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [OAuth 连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [将 Tableau Cloud Web 制作连接到 Salesforce Data Cloud](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [SAP HANA 的外部 OAuth](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [Snowflake 的外部 OAuth](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [设置 Amazon Redshift IAM OAuth](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [设置 Amazon Redshift IAM Identity Center OAuth](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [配置 Snowflake 进行密钥对身份验证](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [管理已保存凭据](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [在 Web 上创建流程并与其进行交互](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [Web 上的 Tableau Prep](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

*   [在 Web 上创建视图并探索数据](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
    *   [Web 制作和 Tableau Desktop 比较](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [设置站点的 Web 制作访问权限](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [在个人空间中创建和编辑私有内容](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用 Tableau Agent 探索您的数据](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [Tableau Agent 常见问题解答](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [创建 Tableau 数据故事（仅限英文）](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [将 Tableau 数据故事添加到仪表板](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [选择适用于您的 Tableau 数据故事的正确故事类型](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [配置 Tableau 数据故事的设置](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [配置 Tableau 数据故事设置：分析](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [配置 Tableau 数据故事设置：特征](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [配置 Tableau 数据故事设置：显示](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [配置 Tableau 数据故事设置：驱动因素](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [配置 Tableau 数据故事设置：叙述](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [配置 Tableau 数据故事设置：关系](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [自定义您的 Tableau 数据故事](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [自定义您的 Tableau 数据故事：上下文变量](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [自定义您的 Tableau 数据故事：函数](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [自定义您的 Tableau 数据故事：隐藏和重新排序内容](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [为您的 Tableau 数据故事添加更多数据](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [将弹出式 Tableau 数据故事添加到仪表板](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [在 Tableau 数据故事中创建自定义度量关系](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [刷新 Tableau 数据故事中的参数](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [在 Tableau 数据故事中使用表计算](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [将 Web 图像动态添加到工作表](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [连接到发布的数据源](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [确定其他人访问您发布的数据的方式](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [编辑已发布数据源](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用动态轴范围](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用动态轴标题](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [动态颜色范围](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用动态区域可见性](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用数据指南浏览仪表板](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [自动保存工作簿](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [拼写检查（仅限 Tableau Cloud 和 Tableau Server）](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用关系进行多表数据分析](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [Tableau 数据模型中的逻辑层和物理层](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [关系与联接有何不同](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [使用性能选项优化关系](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [关于多事实关系数据模型](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [何时使用多事实关系模型](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [构建多事实关系数据模型](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [了解多事实关系数据模型的工具提示](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用“数据问答”（Ask Data）功能自动生成视图](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [创建针对特定受众聚焦“数据问答”(Ask Data) 功能的镜头](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [为站点禁用或启用“数据问答”(Ask Data) 功能](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [针对“数据问答”（Ask Data）功能（Ask Data）优化数据](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用“数据解释”功能更快地发现见解](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [“数据解释”功能入门](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [解释类型](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [查看分析的字段](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [使用“数据解释”功能的要求和注意事项](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [控制对“数据解释”功能的访问](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [“数据解释”功能的工作原理](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [为站点禁用或启用“数据解释”功能](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用加速器快速可视化数据](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用仪表板扩展程序](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [将可视化项扩展程序添加到您的工作表](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [集成外部操作](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [设置动画格式](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [自定义日期格式](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [设置数字和 Null 值的格式](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用辅助技术导航可视化项](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [URL 动作](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [回收站](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [订阅视图](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用自定义视图](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [将视图发布到 Salesforce](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [面向 Data Cloud 的可视细分创建](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用令牌身份验证配置 Tableau Lightning Web 组件和单点登录 (SSO)](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [利用 Tableau Lightning Web 组件实现用户属性函数 (UAF)](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [配置 Tableau 视图 Lightning Web 组件](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [配置 Tableau Pulse Lightning Web 组件](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用适用于 Slack 的 Tableau 应用程序](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [与 Tableau Server 上的数据交互](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [创建指标并排查其问题](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [为查询缓存和视图加速设置数据新鲜度策略](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

*   [使用 Tableau 进行部署](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

*   [Tableau Next](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
    *   [Tableau Next 概述](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [Tableau Next 设置指南](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [步骤 0：预配置清单](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [步骤 1：激活您的 Salesforce 组织](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [步骤 2：配置 Data Cloud 并启用 Tableau Next](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [步骤 3：启用生成式 AI](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [步骤 4：启用 Tableau Next AI 功能](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [步骤 5：设置和管理 Slack 和指标见解摘要](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [步骤 6：连接、转换和协调 Data Cloud 中的数据](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [步骤 7：构建 Tableau Next](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [了解 Salesforce 和 Data Cloud 术语](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [Tableau 的产品和功能](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

*   [Tableau Pulse](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
    *   [为 Tableau Pulse 设置站点](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用 Tableau Pulse 创建指标](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用 Tableau Pulse 探索指标](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用 Tableau Pulse 设置手动目标](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [在 Tableau Pulse 中提出问题并发现见解](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [Tableau Pulse 中的见解平台和见解类型](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [获取 Tableau Pulse 通知](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [使用 Tableau Pulse 指标和仪表板](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [高级 Tableau Pulse 功能](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [设置 Pulse for Salesforce 应用程序](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

*   [Data Management](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
    *   [许可 Data Management](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [资源块](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [Tableau Prep Conductor](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [关于流程工作区](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [在 Tableau Cloud 站点上启用 Tableau Prep Conductor](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [计划流程任务](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [通知用户流程运行成功](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [管理流程](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [监视流程运行状况和性能](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [流程的管理视图](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [Tableau Catalog](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [虚拟连接和数据策略](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [创建虚拟连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [为行级安全性创建数据策略](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [使用“以用户身份预览”测试行级安全性](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [发布虚拟连接并设置权限](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [为虚拟连接计划数据提取刷新](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [使用虚拟连接](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

*   [Advanced Management](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
    *   [活动日志](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [设置活动日志](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [使用活动日志审核权限](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [活动日志租户事件类型参考](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [活动日志站点事件类型参考](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [使用活动日志监控数据导出](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [使用活动日志监控视图加载时间](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [客户管理的加密密钥](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

    *   [Content Migration Tool](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
        *   [Tableau Content Migration Tool 入门](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [安装 Tableau Content Migration Tool](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [使用 Tableau Content Migration Tool](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [Tableau Content Migration Tool 用例](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [迁移规划概述](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [迁移限制](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [迁移计划：站点](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [迁移计划：源项目](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [迁移计划：工作簿](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [迁移计划：已发布数据源](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [迁移计划：权限和所有权](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [迁移计划：迁移脚本](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [迁移计划：计划选项](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [迁移使用数据提取的工作簿和数据源](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

            *   [迁移包含嵌入式凭据的工作簿和数据源](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [使用 Tableau Content Migration Tool 控制台运行程序](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)
            *   [示例：编写迁移计划脚本](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [使用 Content Migration Tool 命令行界面](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [Tableau Content Migration Tool 设置](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

        *   [Tableau Content Migration Tool 日志文件](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)

使用 Tableau Agent 探索您的数据
-----------------------

适用于： Data Cloud

自 2025 年 10 月 14 日起，Data Cloud 已更名为 Data 360。在此过渡期间，您可能会在我们的应用程序和文档中看到对 Data Cloud 的引用。虽然名称是新的，但功能和内容保持不变。

Tableau Agent 是一项生成式 AI 功能，可帮助您在对话助手的帮助下探索数据、创建可视化项并发现见解。连接到工作簿或数据源，并使用自然语言进行可视化分析。结合使用 Tableau Agent 和 Tableau UI 来更快地获得见解。借助 Tableau Agent，盯着空白画布的烦恼已成为过去。

在 Tableau 制作体验中，您可以在工作表中打开 Tableau Agent 对话窗格。Tableau Agent 可以帮助完成以下任务：

*   **快速启动分析**：Tableau Agent 可以根据您的数据提出分析问题
*   **构建可视化项**：“每位导演拍了多少部动作片？”
*   **选择最适合分析的图表类型**：“显示学生成绩的分布”
*   **执行时间序列分析**：“与上个月相比，哪个月的捐赠者数量增长最多？”
*   **创建计算字段**：“创建一个字段，计算案件开庭日期和结案日期之间的差值，并四舍五入到周数”
*   **解释计算**：“解释一下‘实际发货天数’的计算方法”
*   **对数据进行筛选和排序**：“只看海水，给我看鱼缸最小的鱼”

Tableau Agent 根据您的数据创建可视化项，就像 Tableau 中的“智能显示”。Tableau Agent 目前支持的图表类型包括：

*   文本
*   热图
*   条形图
*   堆叠条形图
*   折线图
*   双折线图
*   区域
*   甘特图
*   盒形图
*   散点图
*   直方图
*   符号图
*   填充地图
*   树形图
*   饼图
*   靶心图
*   气泡图

有关 Tableau 图表类型的详细信息，请参见[选择适用于您的数据的正确图表类型(链接在新窗口中打开)](https://help.tableau.com/current/pro/desktop/zh-cn/what_chart_example.htm)。

**注意**：若要使用此功能，您必须登录到具有 Tableau+ 的 Tableau Cloud 站点，并且必须在站点设置中启用 Tableau 中的 AI。如果您没有 Tableau+，但想要尝试 Tableau Agent 功能，您可以报名免费试用 Tableau Cloud，现已包含 Tableau Agent 功能。若要开始试用，请填写此[表单](https://www.tableau.com/zh-cn/products/trial)，或联系您的客户经理。有关免费试用版或配置 Tableau 中的 AI 的详细信息，请参见[为您的站点启用 Tableau 中的 AI(链接在新窗口中打开)](https://help.tableau.com/current/online/zh-cn/setup_tabAI_site_setting.htm)。 

从版本 2025.3 开始，如果您登录到启用了 Tableau 中的 AI 的 Tableau Server 站点，您也可以使用 Tableau Agent。有关详细信息，请参见[在 Tableau Server 站点中启用 AI(链接在新窗口中打开)](https://help.tableau.com/current/server/zh-cn/sites_gai_server.htm)。

[](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#) Tableau Agent 和信任
--------------------------------------------------------------------------------------------

Tableau Cloud 中的 Tableau Agent 建立在 [Einstein 信任层(链接在新窗口中打开)](https://help.tableau.com/current/tableau/zh-cn/tableau_gai_einstein_trust_layer.htm)之上，并继承了其所有安全、治理和信任功能。当您与 Tableau Agent 交互时，发送到大型语言模型 (LLM) 的数据和对话都不会保存到 LLM，并且不会使用任何客户数据来训练模型。

Tableau Agent 仅适用于您的工作簿连接到的数据源。它不知道任何其他 Tableau 数据源，因此无法建议相关内容、回答数据世系问题或回答常识问题。尊重用户定义的行和列级别安全策略。用户在使用 Tableau Agent 时可以访问的数据符合您制定的任何行或列级安全策略。

当您第一次打开 Tableau Agent 时，它会对您的数据进行索引以了解上下文。这有助于 Tableau Agent 根据您的问题和数据源返回相关结果。它索引的信息包括字段元数据（字段标题、来自 Tableau Desktop 或 Tableau Catalog 中的注释的字段描述、数据角色和数据类型），如果数据类型为字符串（文本），则还包括多达 1000 个唯一字段值的样本。

Tableau Agent 使用字段标题或别名，而不是原始字段名称。例如，如果您将“Host”重命名为“Owner”，Tableau Agent 将识别“Owner”，但可能无法识别“Host”。同样，如果为“SessionType1”创建像“Breakout”这样的[别名(链接在新窗口中打开)](https://help.tableau.com/current/pro/desktop/zh-cn/datafields_fieldproperties_aliases_ex1editing.htm) ，它将识别“Breakout”，但不能识别“SessionType”。Tableau Agent 可以索引作为注释包含的字段描述。有关添加注释的详细信息，请参见[为特定字段添加默认注释(链接在新窗口中打开)](https://help.tableau.com/current/pro/desktop/zh-cn/datafields_fieldproperties.htm?#add-default-comments-for-specific-fields)。

Einstein 信任层可用于在将个人身份信息 (PII) 发送到 LLM 之前使用基于模式的数据屏蔽对其进行屏蔽。使用机器学习和模式匹配技术，提示中的 PII 会替换为通用标记，然后在响应中使用原始值解除屏蔽。有关如何配置数据屏蔽的详细信息，请参见 Salesforce 帮助中的[选择要屏蔽的数据(链接在新窗口中打开)](https://help.salesforce.com/s/articleView?id=ai.generative_ai_mask_select.htm&type=5)。为了提供额外的保护，Einstein 信任层保证在 LLM 处理提示和答复之后，LLM 会忘记提示和答复。

如果您在 Tableau Server（版本 2025.3 及更高版本）中使用 Tableau Agent，它不使用 Einstein 信任层。相反，您可以直接连接到大型语言模型提供程序。有关详细信息，请参见 [Tableau 中的 AI 和信任(链接在新窗口中打开)](https://help.tableau.com/current/tableau/zh-cn/tableau_gai_einstein_trust.htm)。

[](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#) Tableau Agent 计费注意事项
-----------------------------------------------------------------------------------------------

**注意**：从 2025 年 10 月开始，Tableau 中的 AI 不再消耗 Einstein Request 积分来使用 AI。其他服务（如 Data Cloud 服务）仍可能消耗其他类型的积分。有关详细信息，请参见 [Einstein Request & Flex Credit Rate Card Updates 常见问题解答(链接在新窗口中打开)](https://help.salesforce.com/s/articleView?id=005197697&type=1)。

当您在 Tableau Cloud 中使用 Tableau 中的生成式 AI 功能时，如果您使用 Einstein 数据收集和存储（也称为审计跟踪）功能作为 Tableau 中的 AI 设置的一部分，它可能会消耗 Data Cloud 积分。有关详细信息，请参见 [Tableau 中的 AI 应用(链接在新窗口中打开)](https://help.tableau.com/current/tableau/zh-cn/tableau_gai_usage.htm)。

您可以使用预先构建的仪表板和数字钱包在 Salesforce 组织中查看您的积分消耗情况，或者从 Tableau 连接到您的 Data Cloud 数据并使用数字钱包表中的数据构建可视化项。有关详细信息，请参见[“查看积分消耗情况”(链接在新窗口中打开)](https://help.tableau.com/current/tableau/zh-cn/tableau_gai_usage_view.htm)。

[](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#) Tableau Agent 入门指南
---------------------------------------------------------------------------------------------

**注意**：如果您使用的是 Salesforce Government Cloud 组织，则不支持 Tableau Agent。

当为您的站点启用 Tableau 中的 AI 时，可通过 Web 制作环境中的对话窗格使用 Tableau Agent。在 Tableau Cloud 中，您可以选择为单个用户组或站点上的所有用户启用它。有关详细信息，请参见[配置 Tableau 中的 AI(链接在新窗口中打开)](https://help.tableau.com/current/online/zh-cn/setup_tabAI_site_setting.htm#configure-ai-in-tableau)。

在以下位置使用 Tableau Agent：

*   Tableau Cloud（需要 Tableau+）

*   Tableau Server（版本 2025.3 及更高版本）

*   Tableau Desktop（版本 2025.1 及更高版本）- 登录到启用了 Tableau 中的 AI 的 Tableau Cloud 或 Tableau Server 站点进行 Web 制作时

Tableau Agent 仅适用于工作表，因此您不会在仪表板或故事中看到此选项。

在 Tableau Cloud 中，您还必须具有 Creator 或 Explorer 站点角色才能使用此功能。

从版本 2025.1 开始，Tableau Agent 支持英语 (en_US) 和其他一些语言。如果您的 Cloud 站点、Server 站点，或 Tableau Desktop 应用程序设置为不受支持的语言，则 Tableau Agent 响应将采用英语 (en_US)。有关受支持语言的详细信息，请参见 [Tableau 中的 AI 支持的语言和区域设置(链接在新窗口中打开)](https://help.tableau.com/current/tableau/zh-cn/tableau_gai_einstein_trust.htm#supported_language)。

首先创建一个新的工作簿或打开一个现有的工作簿。对于新的工作簿，首先要连接到数据。为了最快获得结果，我们建议将 Tableau Agent 与数据提取一起使用。但是，您也可以将 Tableau Agent 与实时数据库连接一起使用，并上载以下文件类型的文件：

*   .hyper

*   .csv

*   .txt

*   .xlsx

Tableau Agent 不支持多维数据集。此外，如果您使用数据混合，Tableau Agent 只能与主数据源一起使用。

### [](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#) 启动 Tableau Agent

若要打开 Tableau Agent 对话窗格，请执行以下操作：

1.   选择工具栏中“智能显示”旁边的 Tableau Agent 图标。

![Image 20: 突出显示了 Tableau Agent 按钮的空白 Tableau 工作表](https://help.tableau.com/current/online/zh-cn/Img/tab_gai_einstein_icon_webauth.png)

2.   窗格打开后，选择“知道了”确认免责声明并开始使用。

![Image 21: 一个空白工作表，打开了 Tableau Agent 对话窗格，显示免责声明文本和“知道了”按钮](https://help.tableau.com/current/online/zh-cn/Img/tab_gai_einstein_gotit.png)

### [](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#)[](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)构建和更改可视化项

Tableau Agent 不是一个开放式的聊天机器人。它只能在您的数据集内工作，并围绕分析和可视化项创建执行一组特定的操作。为了了解您的数据，Tableau Agent 首先对您所连接的数据集进行索引。如果您连接到多个数据集，它将使用“数据”窗格中显示的选定数据集。Tableau Agent 仅适用于数据混合中的主要数据源。

**注意**：如果您在 Tableau Agent 处理请求时切换到其他数据源，则可能会导致错误。等待 Tableau Agent 响应后再更改数据源；然后使用该数据源发出新请求。

索引操作会扫描字段名称、数据类型（例如日期、文本或数字字段），并对 1000 个唯一字段值进行采样，以了解该字段中的数据类型。当发生更改（例如重命名字段或创建新的计算字段）时，会定期重新编制索引。

索引完成后，Tableau Agent 会提供一些建议问题，您可以询问有关数据的问题以帮助您入门，或者使用自然语言在文本框中输入您自己的问题来描述您想要的内容。

![Image 22: 展示由 Tableau Agent 构建的可视化项的工作表。对话窗格已打开并显示突出显示的问题。](https://help.tableau.com/current/online/zh-cn/Img/tab_gai_einstein_web_auth_questions.png)

在 Tableau Agent 创建可视化项后，您可以进行交互并对其进行修改，就像分析师构建并与您共享可视化项一样。通过 Tableau Agent 询问更多问题，以进一步迭代和探索您的数据，使用“建议”来获得更多关于您可以提问的问题的想法，或者直接在 Tableau 界面中掌控全局并继续自己的分析。

如果 Tableau Agent 创建的可视化项不符合您的预期，您可以通过在文本框中输入所需内容来提供其他信息，或者尝试选择“使用 Einstein 重试”![Image 23: 带有弯曲箭头的按钮用于重新生成建议的问题](https://help.tableau.com/current/online/zh-cn/Img/tab_gai_einstein_retry_button.png)，Tableau Agentn 将再次查询 LLM 并对您的请求提供新的响应。

### [](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#)[](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)使用建议快速开始分析

无论您面对的是一张空白画布还是进行更深入的分析，Tableau Agent 都可以通过提出问题来帮助您更深入地挖掘数据。在开始之前，请选择“建议”按钮，Tableau Agent 将根据您的数据源创建三个您可能会问的问题。若要查看更多问题，请选择“使用 Tableau Agent 重试”![Image 24: 带有弯曲箭头的按钮用于重新生成建议的问题](https://help.tableau.com/current/online/zh-cn/Img/tab_gai_einstein_retry_button.png)。

选择一个问题，Tableau Agent 就会为您创建相应的可视化项。

![Image 25: 一个空白画布，其中打开了 Tableau Agent 窗格，显示“建议”按钮。](https://help.tableau.com/current/online/zh-cn/Img/tab_gai_blank_slate.png)

与 Tableau Agent 创建的可视化项进行交互时使用建议来更深入地进行分析。

此外，从版本 2025.1 开始，当您使用 Tableau Agent 创建或修改计算并接受该计算时，Tableau Agent 会提供有关如何在分析中使用该计算的建议。

在 Tableau Agent 的确认回复底部，选择“建议”按钮，Tableau Agent 将建议您可以采取一些措施来发现有关数据的更多见解。当您执行此操作时， “建议”按钮将转换为“重新创建”按钮，以便您可以返回并重新创建上一个可视化项（如果需要）。

只需选择一个选项即可将建议的操作应用于您的可视化项。如果您不喜欢这些建议，只需选择“使用 Tableau Agent 重试”![Image 26: 带有弯曲箭头的按钮用于重新生成建议的问题](https://help.tableau.com/current/online/zh-cn/Img/tab_gai_einstein_retry_button.png)查看更多选项。

![Image 27: 打开了 Tableau Agent 窗格的可视化项，显示了后续分析步骤的建议。 ](https://help.tableau.com/current/online/zh-cn/Img/tab_gai_viz_suggestions.png)

### [](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#)[](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)创建计算

在 Tableau 中构建计算有时会很棘手。如果您是 Tableau 新手，您可能不知道应使用正确的语法或如何正确格式化您的计算。Tableau Agent 可以为您完成繁重的工作，让您保持分析的流畅。

只需让 Tableau Agent 帮助您使用自然语言创建计算来描述您想要做的事情。Tableau Agent 可以执行以下操作：

*   打开计算编辑器

*   添加建议的语法

*   命名计算

*   在 Tableau Agent 窗格中提供计算的解释，以帮助您评估其准确性并提高熟练程度

检查计算，根据需要进行编辑并接受。Tableau Agent 将新的计算字段添加到“数据”窗格，可供您在分析中使用。

有两种方法可以寻求计算帮助：

1.   **在对话窗格中**：在对话流程中，请 Tableau Agent 为您进行计算。只需使用自然语言描述您的计算，Tableau Agent 就会完成剩下的工作。

![Image 28: 带有条形图和计算编辑器对话框的工作表已打开，其中显示了由 Tableau Agent 创建的计算。](https://help.tableau.com/current/online/zh-cn/Img/tab_gai_einstein_calc.png)

2.   **在计算编辑器中**：打开计算编辑器并选择 Tableau Agent![Image 29: Tableau Agent 图标](https://help.tableau.com/current/online/zh-cn/Img/tab_gai_desktop_agent_icon.png) 图标。如果对话窗格尚未打开，此操作会将其打开。如果对话窗格已打开，只需在文本框中输入您的计算描述，Tableau Agent 就会将建议的语法直接添加到打开的计算编辑器中。

![Image 30: “计算编辑器”对话框，其中突出显示了 Einstein 图标](https://help.tableau.com/current/online/zh-cn/Img/tab_gai_einstein_calc_editor.png)

#### 创建计算的提示

当要求 Tableau Agent 帮助您进行计算时，为了获得最佳结果，请具体说明。当您的目标是让 Tableau Agent 为您编写计算时，请使用该特定语言。例如，“创建一个计算...”，“编写一个计算...”，“创建一个计算字段...”，或者只是“计算...”

避免太过笼统也很重要。例如，不要说“找出我最赚钱的产品”，而是尝试“根据产品名称计算利润率”。

这有助于 Tableau Agent 理解您的意图（创建计算）以及您想要计算的字段的含义。

#### 计算描述

理解计算的作用与创建计算本身一样重要。Tableau Agent 可帮助完成该操作。

无论是 Tableau Agent 为您创建的计算，还是作为数据集的一部分存在的计算，您都可以要求 Tableau Agent 解释该计算。例如，“解释订单和发货之间的工作日计算。”

这不仅可以帮助您验证计算是否符合您的需要，还可以帮助您熟练地在 Tableau 分析中使用计算字段。

![Image 31: 显示计算描述的 Tableau Agent 对话窗格。](https://help.tableau.com/current/online/zh-cn/Img/tab_gai_einstein_calc_description_extended.png)

#### 编辑计算

您可以随时编辑 Tableau Agent 为您创建的任何计算。您可以手动编辑计算，也可以让 Tableau Agent 帮助您。

若要编辑计算，请执行以下操作：

1.   在对话窗格中，找到要编辑的计算。

2.   单击“Edit”（编辑）。

3.   在计算编辑器中手动进行更改，然后单击“确定”，或者在 Tableau Agent 对话窗格中描述您想要进行的更改，然后让 Tableau Agent 为您进行更改。

![Image 32: 显示条形图的可视化项，其中打开了计算编辑器和 Tableau Agent 对话窗格。在对话窗格中，“编辑”按钮突出显示。](https://help.tableau.com/current/online/zh-cn/Img/tab_gai_einstein_calc_edit.png)

若要让 Tableau Agent 更新“数据” 窗格中的现有计算，请先在“计算编辑器”中打开计算。

1.   在“数据”窗格中右键单击按住 Cmd 单击 (MacOS) 字段。

2.   选择“编辑…”

3.   在计算编辑器中手动进行更改，然后单击“确定”，或者在 Tableau Agent 对话窗格中描述您想要进行的更改，然后让 Tableau Agent 为您进行更改。

#### 计算限制

使用 Tableau Agent 创建计算时，以下功能尚不受支持：

*   在创建计算时，Tableau Agent 还不能提出澄清问题。您可能需要具体说明或进行迭代，例如，如果有多个字段的名称中包含“name”一词，则指定“将字段 FIRST NAME 更改为正确的大小写”。

*   可用的计算可能因连接类型而异。例如，某些日期函数（例如 [DATEPARSE(链接在新窗口中打开)](https://help.tableau.com/current/pro/desktop/zh-cn/functions_functions_date.htm#dateparse)）仅受数据提取和一部分可能的连接器支持。

如果您的请求涉及实时数据连接不支持的函数，Tableau Agent 可能会为您创建计算，但计算将处于错误状态。若要使用计算，您首先需要提取数据源。在某些情况下您可以请求替代函数，例如使用 DATE 而不是 DATEPARSE。有关这些替代项的详细信息，请参见[函数文档(链接在新窗口中打开)](https://help.tableau.com/current/pro/desktop/zh-cn/functions_all_categories.htm)。

*   Tableau Agent 无法创建计算，然后自动在可视化项中使用它。相反，这是一个两步过程。请求计算并将其添加到“数据”窗格;然后请求可视化项并按名称引用新的计算字段。

### [](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#) 使用筛选器

您可以要求 Tableau Agent 使用自然语言筛选您的可视化项。虽然 Tableau Agent 会尽力理解您的请求并返回解决方案，但有时它可能需要您的帮助才能返回您想要的答复。例如，如果您有高基数字段，即具有很多值的字段，Tableau Agent 可能会要求您选择所需的值。

在这种情况下，您可以在 Tableau Agent 窗格中选择“添加筛选器”，Tableau Agent 会为您打开“筛选器”对话框。只需选择所需的值并选择“确定”即可将筛选器添加到可视化项。

![Image 33: 带有 Tableau Agent 窗格的可视化项画布，描述如何添加筛选器和打开筛选器对话框。](https://help.tableau.com/current/online/zh-cn/Img/tab_gai_einstein_filter.png)

### [](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#) 对话历史记录和可视化项重新创建

您可以在对话窗格中与 Tableau Agent 进行交互。该窗格是 Tableau Agent 提供分析建议并维护该会话的对话历史记录的地方。如果您提出新问题，可视化项本身会更新，但对话窗格会保留您的所有请求和 Tableau Agent 的回复的历史记录。

它还具有交互元素，例如“使用 Tableau Agent 重试”![Image 34: 带有弯曲箭头的按钮用于重新生成建议的问题](https://help.tableau.com/current/online/zh-cn/Img/tab_gai_einstein_retry_button.png) 要求 Tableau Agent 使用相同请求再次查询 LLM 并创建可视化项的另一个版本，或者“重新创建”![Image 35: “重新创建”按钮](https://help.tableau.com/current/online/zh-cn/Img/tab_gai_recreate_button.png)返回返回到之前的可视化项而不查询 LLM，保持相同的结果。

如果您在同一会话中关闭并重新打开对话窗格，您的对话历史记录将会保留。如果您关闭工作簿，这将清除与 Tableau Agent 的对话。对话历史记录未保存，并且不会在您下次打开已发布或已保存的工作簿时出现。

Tableau Agent 是一种基于每张工作表的体验。您无法了解工作簿中的其他工作表，并且无法在工作表之间共享对话。如果您切换到新的工作表，这将开始新的对话。

如果您想让 Tableau Agent 忘记您迄今为止所做事情的背景，请开始一个新工作表，这样对话窗格中就没有历史记录。

[](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#)[](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)从 Tableau Agent 获得最佳结果的技巧
----------------------------------------------------------------------------------------------------------------------------------------------------------------------------

Tableau Agent 尽力理解您的意图和数据。但它仍在学习中。使用以下技巧可以帮助 Tableau Agent 发挥最佳作用并为您提供出色的结果。

| 技巧 | 问题 | 要执行的操作 |
| --- | --- | --- |
| **使用整洁的数据** | 杂乱的数据很难分析，而且 Tableau Agent 不知道如何为您清理和准备数据。 | * 使用[已认证数据源(链接在新窗口中打开)](https://help.tableau.com/current/pro/desktop/zh-cn/datasource_recommended.htm)。数据质量越好，Tableau Agent 返回的结果就越好。 * 在分析之前清理并准备杂乱的数据。 * 确保字段名称具有描述性且唯一。 |
| **隐藏不相关的字段** | 数据集中类似命名的字段可能会让 Tableau Agent 感到困惑。 | 隐藏您不需要的字段，Tableau Agent 将不会使用这些隐藏字段。 |
| **谨慎使用同义词** | Tableau Agent 对于常见同义词的理解做得很好。例如，它知道“片名”和“影片”可以应用于名为“电影”的领域。但是，它不知道您可能使用的任何公司特定术语或缩写。 | 参考您感兴趣的特定字段，以帮助 Tableau Agent 更加准确。 |
| **明确您的意图** | Tableau Agent 会尽力推断您的意图，但可能并不总是正确的。 | 如果您知道您想要 Tableau Agent 生成可视化项，请在请求中使用诸如“向我展示”、“创建可视化项”、“构建条形图”之类的线索。或者，如果您希望 Tableau Agent 创建一个计算，请尝试以短语“创建一个计算...”作为您的请求的开头 |
| **指定如何评估“顶级”** | 诸如“顶级产品”、“最佳销售人员”、“最高季度”之类的请求对于 Tableau Agent 来说可能会很模糊，它可能不知道如何评估什么是“顶级”、“最佳”或“最高”。 | 说明如何衡量和显示“排名靠前”。例如，尝试让 Tableau Agent 向您展示“按利润排名前 10 的产品”或“按销量排名前 3 的产品”。 |
| **在请求中使用特定术语** | Tableau Agent 可以扫描您的数据源以查找字段名称和这些字段中的数据，但它无法像人类一样真正理解数据。 | 您的请求描述得越详细，Tableau Agent 提供相关的可视化项的能力就越强。如果您知道应该使用 MEDIAN 而不是 AVERAGE 聚合来评估您的数据，请指定该聚合。 |
| **分解复杂任务** | Tableau Agent 无法更新数据模型并作为单个步骤的一部分生成可视化项。 | 将任务分解成几个部分并进行迭代。例如： * <任务 1>“创建一个名为利润的计算” * <任务 2>“向我展示利润随时间如何变化” |
| **只询问有关您的数据的问题** | Tableau Agent 并不是一个通用的聊天机器人。它无法回答诸如“我应该如何分析我的数据？”之类的咨询问题，也无法回答诸如“哪种猫最适合做宠物？”之类的一般性问题。 | 提出针对分析数据的问题，并迭代和深入挖掘可视化项结果。 |

[](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#) 实现人机回环
---------------------------------------------------------------------------------

与所有 AI 一样，回顾使用 Tableau Agent 时获得的结果非常重要。当您提出问题时，Tableau Agent 会尽力理解您的数据和意图，但它可能并不总是正确的。

例如，Tableau Agent 尝试为日期粒度（如年、月或日）或聚合（如中位数或平均值）选择默认值。如果您知道您想要的聚合，最好在请求中指定它。

如果 Tableau Agent 弄错了，您可以重新陈述您的请求并阐明您想要什么，也可以直接与可视化项进行交互。毕竟，您处于标准制作环境中，可以访问 Tableau 的所有功能。

您还可以随时通过每个 Tableau Agent 回复中显示的“赞成”或“反对”按钮对结果提供反馈。

![Image 36: 突出显示了反馈按钮的 Einstein Copilot 对话窗格](https://help.tableau.com/current/online/zh-cn/Img/tab_gai_feedback1.png)

如果您单击“反对”选项，请提供其他反馈以帮助改善 Tableau Agent 回复。

![Image 37: 显示 Einstein Copilot 反馈选项的对话框](https://help.tableau.com/current/online/zh-cn/Img/tab_gai_feedback2.png)

[](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#)[](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm)Tableau Agent 限制
-------------------------------------------------------------------------------------------------------------------------------------------------------------------

Tableau 为人类分析师提供了强大的工具，Tableau Agent 也不例外。Tableau 中的 AI 并非旨在取代分析师和数据探索者；它只是为您提供助力。您的参与对于这一过程至关重要。

### [](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#) 分析的类型

Tableau Agent 还不能处理诸如“我应该如何分析我的数据？”或“这些数据有季节性吗？”之类的咨询性问题。相反，您需要指定您想要看到的内容，例如“我的销售额在一段时间内是多少？”

### [](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#) 不支持的功能

Tableau Agent 暂时还无法使用 Tableau 的所有制作功能。目前，如果您连接到在站点设置中启用了 Tableau+ 和 Tableau 中的 AI 的 Tableau Cloud 站点，或者连接到启用了 Tableau 中的 AI 的 Tableau Server 站点（版本 2025.3 及更高版本），则可以在 Web 制作和 Tableau Desktop（从版本 2025.1 开始）中使用。

Tableau Agent 目前无法实现的功能包括：

*   为您选择数据源或进行数据建模（例如创建联接或关系）

*   更改数据类型、字段角色或标题名称

*   设置可视化项的格式。例如，向“标记”卡属性添加字段。例如详细信息或工具提示。

*   添加参考线

*   使用组、集或参数来组织或自定义字段

*   使用筛选器控件、参数和操作等元素创建交互性

*   构建仪表板

*   分析大型数据集。如果您的数据集中有数百或数千个字段，尤其是当它们的名称相似时，Tableau Agent 将无法正常工作。如果您尝试筛选高基数的字段（单个字段有许多不同的值），Tableau Agent 可能需要您手动执行筛选操作。

*   块索引在数据模型更改后刷新

*   支持所有语言。Tableau Agent 支持英语 (en_US) 和其他一些语言。如果您的数据源字段名称和值与您的用户语言设置不同或与您与 Agent 交互的语言不同，请在您的请求中使用准确的字段名称和值。有关 Tableau Agent 当前支持的语言的信息，请参见 [Tableau 中的 AI 支持的语言和区域设置(链接在新窗口中打开)](https://help.tableau.com/current/tableau/zh-cn/tableau_gai_einstein_trust.htm#supported_language)。

[](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#) 此部分中的其他文章
------------------------------------------------------------------------------------

*   [Tableau Agent 常见问题解答](https://help.tableau.com/current/online/zh-cn/web_author_einstein_faq.htm)

[回到顶部](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#)

 这篇文章解决了您的问题吗?  让我们知道，这样我们才能改进！ 

 是  否 

 本文内容 

*   [Tableau Agent 和信任](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#tableau-agent-%E5%92%8C%E4%BF%A1%E4%BB%BB)
*   [Tableau Agent 计费注意事项](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#tableau-agent-%E8%AE%A1%E8%B4%B9%E6%B3%A8%E6%84%8F%E4%BA%8B%E9%A1%B9)
*   [Tableau Agent 入门指南](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#tableau-agent-%E5%85%A5%E9%97%A8%E6%8C%87%E5%8D%97)
*   [启动 Tableau Agent](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E5%90%AF%E5%8A%A8-tableau-agent)
*   [构建和更改可视化项](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E6%9E%84%E5%BB%BA%E5%92%8C%E6%9B%B4%E6%94%B9%E5%8F%AF%E8%A7%86%E5%8C%96%E9%A1%B9)
*   [使用建议快速开始分析](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E4%BD%BF%E7%94%A8%E5%BB%BA%E8%AE%AE%E5%BF%AB%E9%80%9F%E5%BC%80%E5%A7%8B%E5%88%86%E6%9E%90)
*   [创建计算](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E5%88%9B%E5%BB%BA%E8%AE%A1%E7%AE%97)
*   [使用筛选器](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E4%BD%BF%E7%94%A8%E7%AD%9B%E9%80%89%E5%99%A8)
*   [对话历史记录和可视化项重新创建](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E5%AF%B9%E8%AF%9D%E5%8E%86%E5%8F%B2%E8%AE%B0%E5%BD%95%E5%92%8C%E5%8F%AF%E8%A7%86%E5%8C%96%E9%A1%B9%E9%87%8D%E6%96%B0%E5%88%9B%E5%BB%BA)
*   [从 Tableau Agent 获得最佳结果的技巧](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E4%BB%8E-tableau-agent-%E8%8E%B7%E5%BE%97%E6%9C%80%E4%BD%B3%E7%BB%93%E6%9E%9C%E7%9A%84%E6%8A%80%E5%B7%A7)
*   [实现人机回环](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E5%AE%9E%E7%8E%B0%E4%BA%BA%E6%9C%BA%E5%9B%9E%E7%8E%AF)
*   [Tableau Agent 限制](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#tableau-agent-%E9%99%90%E5%88%B6)
*   [分析的类型](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E5%88%86%E6%9E%90%E7%9A%84%E7%B1%BB%E5%9E%8B)
*   [不支持的功能](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E4%B8%8D%E6%94%AF%E6%8C%81%E7%9A%84%E5%8A%9F%E8%83%BD)
*   [此部分中的其他文章](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#%E6%AD%A4%E9%83%A8%E5%88%86%E4%B8%AD%E7%9A%84%E5%85%B6%E4%BB%96%E6%96%87%E7%AB%A0)

*   [法律](https://www.salesforce.com/company/legal/)
*   [服务条款](https://www.salesforce.com/company/legal/sfdc-website-terms-of-service/)
*   [隐私信息](https://www.salesforce.com/cn/company/privacy/)
*   [负责任的披露](https://www.salesforce.com/cn/company/disclosure/)
*   [Trust](https://trust.salesforce.com/cn)
*   [联系方式](https://www.salesforce.com/cn/form/contact/contactme/)
*   [Cookie 首选项](https://help.tableau.com/current/online/zh-cn/web_author_einstein.htm#)
*   [您的隐私选择](https://www.salesforce.com/form/other/privacy-request/)

 © Copyright 2026 Salesforce, Inc. [保留所有权利。](https://www.salesforce.com/company/legal/tmcusageguidelines/) 各自所有者持有的各种商标。Salesforce, Inc. 

![Image 38: Company Logo](https://a.sfdcstatic.com/enterprise/tableau/prod/2024012/v1/oneTrust/consent/2d08f29e-0ede-4e8c-997c-f7ef5be8d4e7/8fefa03d-ef3b-4caa-976f-f01af2e7f932/logos/ddb906c9-f57b-40fc-85a1-c8bcbc371b0d/6a33a761-886e-4860-8e17-abc0832f7a62/corporate_logo_big.png)

Cookie Consent Manager
----------------------

*   ### General Information 
*   ### Required Cookies 
*   ### Functional Cookies 
*   ### Advertising Cookies 

#### General Information

We use three kinds of cookies on our websites: required, functional, and advertising. You can choose whether functional and advertising cookies apply. Click on the different cookie categories to find out more about each category and to change the default settings. 

[Privacy Statement](https://www.salesforce.com/company/privacy/full_privacy/)

#### Required Cookies

Always Active

Required cookies are necessary for basic website functionality. Some examples include: session cookies needed to transmit the website, authentication cookies, and security cookies.

Cookies Details‎

#### Functional Cookies

- [x] Functional Cookies 

Functional cookies enhance functions, performance, and services on the website. Some examples include: cookies used to analyze site traffic, cookies used for market research, and cookies used to display advertising that is not directed to a particular individual.

Cookies Details‎

#### Advertising Cookies

- [x] Advertising Cookies 

Advertising cookies track activity across websites in order to understand a viewer’s interests, and direct them specific marketing. Some examples include: cookies used for remarketing, or interest-based advertising.

Cookies Details‎

### Cookie List

Consent Leg.Interest

- [x] checkbox label label

- [x] checkbox label label

- [x] checkbox label label

Clear

- [x] checkbox label label

Apply Cancel

Save Settings

Accept All Cookies

[![Image 39: Powered by Onetrust](https://a.sfdcstatic.com/enterprise/tableau/prod/2024012/v1/oneTrust/consent/2d08f29e-0ede-4e8c-997c-f7ef5be8d4e7/8fefa03d-ef3b-4caa-976f-f01af2e7f932/logos/static/powered_by_logo.svg)](https://www.onetrust.com/products/cookie-consent/)

![Image 40](https://id.rlcdn.com/464526.gif)